@@ -155,6 +155,10 @@ struct config {
 
     uint16_t resize_delay_ms;
 
+    struct {
+        float amount;
+    } dim;
+
     struct {
         bool enabled;
         bool palette_based;
@@ -254,6 +258,12 @@ struct config {
         uint32_t dim[8];
         uint32_t sixel[16];
 
+        enum {
+            ALPHA_MODE_DEFAULT,
+            ALPHA_MODE_MATCHING,
+            ALPHA_MODE_ALL
+        } alpha_mode;
+
         struct {
             uint32_t fg;
             uint32_t bg;
