@@ -88,7 +88,7 @@ struct range {
 
 struct cursor {
     struct coord point;
-    bool lcf;
+    bool lcf; /* Last Column Flag; https://github.com/mattiase/wraptest#basic-vt-line-wrapping-rules */
 };
 
 enum damage_type {DAMAGE_SCROLL, DAMAGE_SCROLL_REVERSE,
@@ -777,6 +777,10 @@ struct terminal {
 
         bool transparent_bg;
 
+        bool linear_blending;
+        bool use_10bit;
+        pixman_format_code_t pixman_fmt;
+
         /* Application configurable */
         unsigned palette_size;  /* Number of colors in palette */
         unsigned max_width;     /* Maximum image width, in pixels */
@@ -789,6 +793,7 @@ struct terminal {
     bool urls_show_uri_on_jump_label;
     struct grid *url_grid_snapshot;
     bool ime_reenable_after_url_mode;
+    const struct config_spawn_template *url_launch;
 
 #if defined(FOOT_IME_ENABLED) && FOOT_IME_ENABLED
     bool ime_enabled;
@@ -893,7 +898,9 @@ void term_cursor_up(struct terminal *term, int count);
 void term_cursor_down(struct terminal *term, int count);
 void term_cursor_blink_update(struct terminal *term);
 
-void term_print(struct terminal *term, char32_t wc, int width);
+void term_process_and_print_non_ascii(struct terminal *term, char32_t wc);
+void term_print(struct terminal *term, char32_t wc, int width,
+                bool insert_mode_disable);
 void term_fill(struct terminal *term, int row, int col, uint8_t c, size_t count,
                bool use_sgr_attrs);
 
